/**
 * @fileOverview Sample for receiving unsolicided events
 * @name index.js
 * @author Cor Kalis <c.kalis@intoaccess.com>
 * @license UNLICENSED
 */
"use strict";

const WebSocket = require('ws');

// Constants defining how to connect
const HOST = '192.168.1.55';
//const HOST = 'localhost';
const PORT = 8088;
const PATH = '/Events';
const USER = 'RestUser';
const PASSWD = 'RestPassword';

// Options for the websocket connection.
// In particular, the authentication part.
const OPTIONS = {
  headers: {
    'Authorization': 'Basic ' + Buffer.from(USER + ':' + PASSWD).toString('base64')
  },
  perMessageDeflate: false
};

// Make a web socket connection
const ws = new WebSocket(`ws://${HOST}:${PORT}${PATH}`, OPTIONS);

ws.on('open', () => {
  console.log('Connection opened');
});

ws.on('close', (code) => {
  console.log(`Connection closed, code ${code}`);
});

ws.on('error', (error) => {
  console.log('Error:', error);
});

ws.on('message', (data) => {
  try
  {
    const json = JSON.parse(data);
    // Pretty print JSON data
    console.log(JSON.stringify(json, null, '  '));
  } catch(err) {
    console.log('Received an invalid JSON object');
  }
});
